=================================
``psyclone.psyir.nodes.datanode``
=================================

.. automodule:: psyclone.psyir.nodes.datanode

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.datanode
